
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.009.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Scan for modules loaded with Importer::Zim",
  "dist_author" => [
    "Adriano Ferreira <ferreira\@cpan.org>"
  ],
  "dist_name" => "Perl-PrereqScanner-Scanner-Zim",
  "dist_version" => "0.2.0",
  "license" => "perl",
  "module_name" => "Perl::PrereqScanner::Scanner::Zim",
  "recursive_test_files" => 1,
  "requires" => {
    "Moose" => 0,
    "PPIx::Literal" => 0,
    "Perl::PrereqScanner::Scanner" => 0,
    "perl" => "5.010",
    "strict" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "File::Spec" => 0,
    "Perl::PrereqScanner" => 0,
    "Test::More" => "0.96"
  }
);


my %fallback_build_requires = (
  "ExtUtils::MakeMaker" => 0,
  "File::Spec" => 0,
  "Module::Build" => "0.28",
  "Perl::PrereqScanner" => 0,
  "Test::More" => "0.96"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
